Implementation of test functions collections for unconstrained optimization based on sympy representation of function.
Functions was taken from https://camo.ici.ro/journal/vol10/v10a10.pdf
Functions list:
    1. Extended Freudenstein & Roth function
    2. Extended Trigonometric function
    3. Extended Rosenbrock function
    4. Generalized Rosenbrock function
    5. Extended WhiteHolst function
    6. Extended Beale function
    7. Extended Penalty function
    8. Raydan 1 function
    9. Raydan 2 function
    10. Hager function
    11. Extended  TET (Three Exponential Terms) function
    12. Extended  Himmelblau function
    13. Generalized WhiteHolst function
    14. Generalized PSC1 function
    15. Extended  PSC1 function
    16. Extended  Powell function
    17. Extended  Maratos function
    18. Extended  Cliff function
    19. Extended Wood function
    20. Extended Hiebert function
    21. Staircase1 function
    22. Staircase2 function
    23. Diagonal 1 function
    24. Diagonal 2 function
    25. Diagonal 3 function
    26. Diagonal 4 function
    27. Diagonal 5 function
    28. Diagonal 6 function
    29. Diagonal 7 function
    30. Diagonal 8 function
    31. Diagonal 9 function
    32. Extended BlockDiagonal  function
    33. Extended Tridiagonal 1 function
    34. Extended Tridiagonal 2 function
    35. Generalized Tridiagonal 1 function
    36. Generalized Tridiagonal 2 function
    37. Broyden Tridiagonal  function
    38. Perturbed Tridiagonal Quadratic function
    39. Perturbed Quadratic function
    40. Quadratic QF1 function
    41. Quadratic QF2 function
    42. Extended Quadratic Penalty function
    43. Extended Quadratic Penalty function
    44. Extended Quadratic Exponential function
    45. Partial Perturbed Quadratic function
    46. Almost PerturbedQ uadratic function
    47. Generalized Quadratic function
    48. Full Hessian 1 function
    49. Full Hessian 2 function
    50. Full Hessian 3 function
    51. FLETCBV3 function
    52. FLETCHCR function
    53. BDQRTIC function
    54. TRIDIA function
    55. ARGLINB function
    56. ARWHEAD function
    57. NONDIA function
    58. NONDQUAR function
    59. DQDRTIC function
    60. EG2 function
    61. CURLY20 function
    62. LIARWHD1 function
    63. POWER function
    64. ENGVAL1 function
    65. CRAGGLVY function
    66. EDENSCH function
    67. INDEF function
    68. CUBE function
    69. EXPLIN1 function
    70. EXPLIN2 function
    71. ARGLINC function
    72. BDEXP function
    73. HARKERP2 function
    74. GENHUMPS function
    75. MCCORMCK function
    76. NONSCOMP function
    77. VARDIM function
    78. QUARTC function
    79. SINQUAD function
    80. Extended DENSCHNB function
    81. Extended DENSCHNF function
    82. LIARWHD2 function
    83. DIXON3DQ function
    84. COSINE function
    85. SINE function
    86. BIGGSB1 function
    87. SINCOS function
    88. HIMMELBG function
    89. HIMMELH function
    90. DIXMAANA
    91. DIXMAANB
    92. DIXMAANC
    93. DIXMAAND
    94. DIXMAANE
    95. DIXMAANF
    96. DIXMAANG
    97. DIXMAANH
    98. DIXMAANI
    99. DIXMAANJ
    100. DIXMAANK
    101. DIXMAANL

